# Largest-small polygon problem

model;

param N integer > 0;          # number of vertices in the polygon
param pi := 3.14159265358979; # approximation of pi

var r {i in 1..N};     # polar radius (distance to fixed vertex)
var theta {i in 1..N}; # polar angle (measured from fixed direction)

maximize polygon_area:
  0.5*sum{i in 1..N-1} r[i+1]*r[i]*sin(theta[i+1] - theta[i]);

subject to r_bounds {i in 1..N}: 0.0 <= r[i] <= 1.0;

subject to theta_bounds {i in 1..N}: 0.0 <= theta[i] <= pi;

subject to fix_theta_N: theta[N] = pi;
subject to fix_r_N: r[N] = 0.0;

subject to ordered_theta {i in 1..N-1}: theta[i] <= theta[i+1];

subject to distance {i in 1..N-1,j in i+1..N}:
  r[i]^2 + r[j]^2 - 2*r[i]*r[j]*cos(theta[j] - theta[i]) <= 1;

subject to convexity {i in 2..N-1}:
  r[i]*r[i-1]*sin(theta[i]-theta[i-1]) + r[i+1]*r[i]*sin(theta[i+1]-theta[i]) >=
    r[i+1]*r[i-1]*sin(theta[i+1]-theta[i-1]);